@@ -387,16 +387,16 @@ class LazyMedia(anvil.Media):
 class AnvilWrappedError(Exception):
     registered_type_name = None
 
-    def __init__(self, error_obj):
-        if isinstance(error_obj, dict):
+    def __init__(self, message=""):
+        if isinstance(message, dict):
             self.manually_created = False
-            self.error_obj = error_obj
+            self.error_obj = message
         else:
             self.manually_created = True
-            self.error_obj = {'message': str(error_obj), 'trace': []}
-            t =  type(self).registered_type_name
+            self.error_obj = {"message": str(message), "trace": []}
+            t = type(self).registered_type_name
             if t is not None:
-                self.error_obj['type'] = t
+                self.error_obj["type"] = t
         self.message = self.error_obj.get("message", "")
         Exception.__init__(self, self.message)
 
@@ -481,11 +481,11 @@ def apply_cache_updates(cache_updates, objects_to_walk):
 
 
 class MaybeWrappedError(Exception):
-    def __init__(self, error_obj):
-        if isinstance(error_obj, dict):
-            Exception.__init__(self, error_obj["message"])
+    def __init__(self, message=""):
+        if isinstance(message, dict):
+            Exception.__init__(self, message["message"])
         else:
-            Exception.__init__(self, error_obj)
+            Exception.__init__(self, message)
 
 
 class SerializationError(MaybeWrappedError):
@@ -548,6 +548,9 @@ class PermissionDenied(MaybeWrappedError):
     pass
 
 
+class ServiceNotAdded(MaybeWrappedError):
+    pass
+
 
 
 _register_exception_type("anvil.server.SerializationError", SerializationError)
@@ -564,6 +567,7 @@ _register_exception_type("anvil.server._FailError", _FailError)
 _register_exception_type("anvil.server.BackgroundTaskError", BackgroundTaskError)
 _register_exception_type("anvil.server.BackgroundTaskNotFound", BackgroundTaskNotFound)
 _register_exception_type("anvil.server.PermissionDenied", PermissionDenied)
+_register_exception_type("anvil.server.ServiceNotAdded", ServiceNotAdded)
 
 
 
@@ -1067,7 +1071,7 @@ def _lower_str(s):
         return s
     return s.lower()
 
-class HttpHeaders():
+class HttpHeaders(object):
 
     def __init__(self, headers=None):
         headers = headers or {}
@@ -1100,7 +1104,7 @@ class HttpHeaders():
         return "HttpHeaders(" + repr(self._headers) + ")"
 
 
-class HttpResponse():
+class HttpResponse(object):
     def __init__(self, status=200, body="", headers=None):
         self.status = status
         self.body = body
@@ -1112,10 +1116,10 @@ class HttpResponse():
 
     @headers.setter
     def headers(self, value):
-        if isinstance(value, HttpHeaders):
-            self._headers = value.copy()
-        elif value is None or isinstance(value, dict):
+        if value is None or isinstance(value, dict):
             self._headers = HttpHeaders(value)
+        elif isinstance(value, HttpHeaders):
+            self._headers = value.copy()
         else:
             raise TypeError("headers should be set to a dictionary")
 
@@ -1391,7 +1395,7 @@ class CookieContainer(object):
 cookies = CookieContainer()
 
 
-class NotABackgroundTaskState():
+class NotABackgroundTaskState(object):
     def __setitem__(self, key, value):
         raise Exception("Cannot access anvil.server.task_state outside a background task")
 
