@@ -138,10 +138,11 @@ default_app = anvil.app
 
 
 class LocalAppInfo(ThreadLocal):
-    def __init__(self):
-        self.__dict__['id'] = default_app.id
-        self.__dict__['branch'] = default_app.branch
-        self.__dict__['environment'] = default_app.environment
+    def __getattr__(self, attr):
+        return getattr(default_app, attr)
+
+    def __setattr__(self, key, value):
+        raise AttributeError("This object is read-only")
 
     def _setup(self, environment={}, **kwargs):
         self.__dict__.update(kwargs, environment=anvil._AppInfo._Environment(**environment))
@@ -183,9 +184,11 @@ class IncomingRequest(_serialise.IncomingReqResp):
             anvil.app._setup(**self.json.get('app-info', {}))
             if self.setup_task_state:
                 self.setup_task_state(call_info.call_id, True)
+            import_complete = False
             try:
                 if self.import_modules:
                     self.import_modules()
+                import_complete = True
 
                 # Now we've imported enough to deserialise custom types
                 self.reconstruct_remaining_data()
@@ -281,6 +284,9 @@ class IncomingRequest(_serialise.IncomingReqResp):
                     else:
                         e['taskState'] = task_state
 
+                if not import_complete:
+                    e['moduleLoadFailed'] = True
+
                 try:
                     send_reqresp(e)
                 except:
